@@ -20,6 +20,7 @@
 #include <QtCore/qdebug.h>
 #include <QtCore/qdir.h>
 #include <QtCore/qfile.h>
+#include <QtCore/qlibraryinfo.h>
 #include <QtCore/qstringlist.h>
 #include <QtCore/qxmlstream.h>
 
@@ -170,7 +171,7 @@ static void msgFormatEnumType(Stream &str,
 {
     switch (enumItem->enumKind()) {
     case CEnum:
-        str << "Enum '" << enumItem->qualifiedName().join(u"::"_s) << '\'';
+        str << "Enum '" << enumItem->qualifiedNameString() << '\'';
         break;
     case AnonymousEnum: {
         const EnumeratorList &values = enumItem->enumerators();
@@ -193,7 +194,7 @@ static void msgFormatEnumType(Stream &str,
     }
         break;
     case EnumClass:
-        str << "Scoped enum '" << enumItem->qualifiedName().join(u"::"_s) << '\'';
+        str << "Scoped enum '" << enumItem->qualifiedNameString() << '\'';
         break;
     }
     if (!className.isEmpty())
@@ -1099,7 +1100,8 @@ QString msgRemoveRedundantOverload(const AbstractMetaFunctionCPtr &func,
 
 QString msgCommandLineArguments(const QStringList &argv)
 {
-    QString result = "Command line:\n   "_L1;
+    QString result = "Host platform: "_L1 + QLatin1StringView(QLibraryInfo::build())
+                     + "\nCommand line:\n   "_L1;
     for (const QString &arg : argv) {
         result.append(u' ');
         const bool quote = arg.contains(u' ');
